@@ -530,7 +530,7 @@ class Score:
         track_list = []
         for staff in self.m_staffs:
             for voice in staff.m_voice_list:
-                track_list.append(voice.generate_track_for_voice(staff, kv, tracktype))
+                track_list.append(voice.generate_track_for_voice(kv, tracktype))
         return track_list
 
 
@@ -652,7 +652,13 @@ class Voice:
                        # need these to generate midi track
                        self.m_coldict[pos1].m_music[p],
                        self.m_coldict[pos2].m_music[p]))
-    def generate_track_for_voice(self, staff, kv, tracktype):
+    def get_event_dict(self, kv):
+        """
+        Return a dict that tell us where every note in the track starts
+        and stops. The key is a Rat, and the values are a list of tuples.
+        Each tuple has thee elements
+        (id, 'start|stop-note', midiint)
+        """
         # first we find the id()'s of music to tie
         tie_from_v = []
         tie_to_v = []
@@ -694,8 +700,9 @@ class Voice:
                         D[stop_pos].append((i, const.STOP_NOTE, n.m_pitch.semitone_pitch()))
                         i = i + 1
             last_timepos = coltimepos
-        return self.__gen_midi_last_step(D, tracktype)
-    def __gen_midi_last_step(self, D, tracktype):
+        return D
+    def generate_track_for_voice(self, kv, tracktype):
+        D = self.get_event_dict(kv)
         keys = D.keys()
         keys.sort()
         prev_time = Rat(0)
@@ -873,13 +880,13 @@ def parse_to_score_object(music):
             timepos = timepos + toc_data.get_rat_value()
         elif toc == Lexer.REST and context == NOTES:
             cur_voice.announce_timepos(timepos)
-            if toc_data:
-                cur_duration = toc_data
+            if toc_data.m_duration:
+                cur_duration = toc_data.m_duration
             else:
-                toc_data = cur_duration
-            cur_voice.add_rest(toc_data, timepos)
+                toc_data.m_duration = cur_duration
+            cur_voice.add_rest(toc_data.m_duration, timepos)
             last_pos = timepos
-            timepos += toc_data.get_rat_value()
+            timepos += toc_data.m_duration.get_rat_value()
         elif toc == Lexer.STEMDIR:
             stem_dir = toc_data
         elif toc == Lexer.TUPLETDIR:
@@ -959,9 +966,9 @@ class Lexer:
                 ret.append("%s%s " % (toc_data.m_pitch.get_octave_notename(),
                     toc_data.m_duration.as_mpd_string() if toc_data.m_duration else ""))
             elif toc == Lexer.SKIP: # 9
-                ret.append("s%s " % (toc_data.as_mpd_string() if toc_data else "",))
+                ret.append("s%s " % (toc_data.m_duration.as_mpd_string() if toc_data.m_duration else "",))
             elif toc == Lexer.REST: # 10
-                ret.append("r%s " % (toc_data.as_mpd_string() if toc_data else "",))
+                ret.append("r%s " % (toc_data.m_duration.as_mpd_string() if toc_data.m_duration else "",))
             elif toc == Lexer.RELATIVE: # 11
                 ret.append(r"\relative %s" % toc_data.get_octave_notename())
             elif toc == Lexer.TIMES: # 12
@@ -1006,11 +1013,10 @@ class Lexer:
                         },
                         self)
             if notelen is 0:
-                retval = None
+                return self.REST, RestRequest(None, None)
             else:
-                self.m_notelen = retval = Duration(notelen, numdots)
-            return self.REST, retval
-
+                self.m_notelen = Duration(notelen, numdots)
+                return self.REST, RestRequest(notelen, numdots)
         m = self.re_skip.match(self.m_string, self.m_idx)
         if m:
             self.m_idx = m.end()
@@ -1027,10 +1033,10 @@ class Lexer:
                         'goodcode':'s%i%s' % (self.m_notelen.m_nh, dots)
                         }, lexer)
             if skiplen is 0:
-                retval = None
+                return self.SKIP, SkipRequest(skiplen, numdots)
             else:
-                self.m_notelen = retval = Duration(skiplen, numdots)
-            return self.SKIP, retval
+                self.m_notelen = Duration(skiplen, numdots)
+                return self.SKIP, SkipRequest(skiplen, numdots)
         m = self.re_melodic.match(self.m_string, self.m_idx)
         if m:
             self.m_idx = m.end()
