@@ -7,6 +7,7 @@ import doctest
 
 import solfege.mpd.duration
 from solfege.mpd.duration import Duration
+from solfege.mpd.rat import Rat
 
 class TestDuration(unittest.TestCase):
     def test_constructor(self):
@@ -14,6 +15,14 @@ class TestDuration(unittest.TestCase):
             d = Duration(a, b)
             r = d.get_rat_value()
             self.assertEquals(float(r), f)
+    def test_misc(self):
+        d1=Duration(4, 0, Rat(1, 1))
+        d2=Duration(4, 1, Rat(1, 1))
+        self.assertFalse(d1 == d2)
+        self.assertEquals(d1.get_rat_value(), Rat(1, 4))
+        self.assertEquals(d2.get_rat_value(), Rat(3, 8))
+        d3=Duration(4, 2, Rat(2, 3))
+        self.assertEquals(d3.get_rat_value(), Rat(7, 24))
 
 suite = unittest.makeSuite(TestDuration)
 suite.addTest(doctest.DocTestSuite(solfege.mpd.duration))
