@@ -284,9 +284,8 @@ static int s_FreeNodes(WinmidiObject *obj) {
 }
 
 
-int s_ResetMidiStream(WinmidiObject *obj) {
+int s_ResetMidiStream(WinmidiObject *obj, UINT devNum) {
 	UINT retVal;
-	UINT devNum;
 
 	assert(obj);
 
@@ -299,7 +298,6 @@ int s_ResetMidiStream(WinmidiObject *obj) {
 	return 0;
 	}
 
-	devNum = 0;
 	retVal = midiStreamOpen(&(obj->m_midiOut), &devNum, 1,
 		(DWORD) s_MidiCallback, (DWORD) obj, CALLBACK_FUNCTION); //lint !e620
 	if(retVal != MMSYSERR_NOERROR) {
@@ -663,8 +661,9 @@ static PyObject *Winmidi_Play(PyObject *self, PyObject *args) {
 
 static PyObject *Winmidi_Reset(PyObject *self, PyObject *args) {
 	WinmidiObject *obj;
+	UINT devNum;
 	
-	if(!PyArg_ParseTuple(args, ":reset")) {
+	if(!PyArg_ParseTuple(args, "i:reset", &devNum)) {
 	return NULL;
 	}
 	obj = (WinmidiObject *) self;
@@ -673,8 +672,7 @@ static PyObject *Winmidi_Reset(PyObject *self, PyObject *args) {
 	return NULL;
 	}
 
-	/* printf("Reset called.\n"); */
-	if(!s_ResetMidiStream(obj)) {
+	if(!s_ResetMidiStream(obj, devNum)) {
 	return NULL;
 	}
 
